import React, { useState, useRef, useEffect, useMemo } from "react";
import {
    CreateBase,
    useTranslate,
    TextInput,
    NumberInput,
    BooleanInput,
    DateInput,
    SaveButton,
    SelectInput,
    ReferenceInput,
    ReferenceArrayInput,
    AutocompleteInput,
    Toolbar,
    required,
    useDataProvider,
    useNotify,
    Form,
    useCreateController,
    useListContext,
    useRefresh,
} from 'react-admin';
import {
    Dialog,
    DialogActions,
    DialogContent,
    DialogTitle,
    Grid,
    TextField,
    Box,
    Button,
    Paper,
    TableContainer,
    Table,
    TableHead,
    TableBody,
    TableRow,
    TableCell,
    Tooltip,
    IconButton,
    styled


} from '@mui/material';
import DialogCloseButton from "../../components/DialogCloseButton";
import { useForm, Controller, useWatch, FormProvider, useFormContext } from "react-hook-form";
import SaveIcon from '@mui/icons-material/Save';
import request from '@/utils/request';
import { Add, Edit, Delete } from '@mui/icons-material';
import _ from 'lodash';
import { DataGrid } from '@mui/x-data-grid';




const InitModal = ({ open, setOpen }) => {
    const refresh = useRefresh();
    const translate = useTranslate();


    const notify = useNotify();

    const [formData, setFormData] = useState({
        "areaId": "",
        "endBay": "",
        "endLev": "",
        "endRow": "",
        "locType": "",
        "startBay": "",
        "startLev": "",
        "startRow": "",
        "type": ""
    });

    const handleClose = (event, reason) => {
        if (reason !== "backdropClick") {
            setOpen(false);
        }
    };

    const handleReset = (e) => {
        e.preventDefault();
    };

    const handleChange = (e) => {
        const { name, value } = e.target;
        setFormData((prevData) => ({
            ...prevData,
            [name]: value
        }));
    };

    const handleSubmit = async () => {
        const res = await request.post(`/loc/init`, formData);
        if (res?.data?.code === 200) {
            setOpen(false);
            refresh();
        } else {
            notify(res.data.msg);
        }
    }


    return (
        <Dialog open={open} maxWidth="md" fullWidth>
            <DialogCloseButton onClose={handleClose} />
            <DialogTitle>{translate('toolbar.locInit')}</DialogTitle>
            <DialogContent sx={{ mt: 2 }}>
                <Box component="form" sx={{ display: 'flex', flexDirection: 'column', gap: 3 }}>
                    <Grid container spacing={2}>
                        <Grid item xs={4}>
                            <TextField
                                label={translate("table.field.loc.areaId")}
                                name="wkType"
                                value={formData.areaId}
                                onChange={handleChange}
                                variant="outlined"
                                size="small"
                                validate={required()}
                            />
                        </Grid>

                        <Grid item xs={4}>
                            <TextField
                                label={translate("table.field.loc.locType")}
                                name="wkType"
                                value={formData.locType}
                                onChange={handleChange}
                                variant="outlined"
                                size="small"
                                validate={required()}
                            />
                        </Grid>

                        <Grid item xs={4}>
                            <TextField
                                label={translate("table.field.loc.type")}
                                name="wkType"
                                value={formData.type}
                                onChange={handleChange}
                                variant="outlined"
                                size="small"
                                validate={required()}
                            />
                        </Grid>

                        <Grid item xs={4}>
                            <TextField
                                label={translate("table.field.loc.startBay")}
                                name="type"
                                value={formData.startBay}
                                onChange={handleChange}
                                variant="outlined"
                                size="small"
                                validate={required()}
                            />
                        </Grid>

                        <Grid item xs={4}>
                            <TextField
                                label={translate("table.field.loc.startLev")}
                                name="wkType"
                                value={formData.startLev}
                                onChange={handleChange}
                                variant="outlined"
                                size="small"
                                validate={required()}
                            />
                        </Grid>

                        <Grid item xs={4}>
                            <TextField
                                label={translate("table.field.loc.startRow")}
                                name="wkType"
                                value={formData.startRow}
                                onChange={handleChange}
                                variant="outlined"
                                size="small"
                                validate={required()}
                            />
                        </Grid>

                        <Grid item xs={4}>
                            <TextField
                                label={translate("table.field.loc.endBay")}
                                name="wkType"
                                value={formData.endBay}
                                onChange={handleChange}
                                variant="outlined"
                                size="small"
                                validate={required()}
                            />
                        </Grid>

                        <Grid item xs={4}>
                            <TextField
                                label={translate("table.field.loc.endLev")}
                                name="wkType"
                                value={formData.endLev}
                                onChange={handleChange}
                                variant="outlined"
                                size="small"
                                validate={required()}
                            />
                        </Grid>

                        <Grid item xs={4}>
                            <TextField
                                label={translate("table.field.loc.endRow")}
                                name="wkType"
                                value={formData.endRow}
                                onChange={handleChange}
                                variant="outlined"
                                size="small"
                                validate={required()}
                            />
                        </Grid>


                    </Grid>
                </Box>
            </DialogContent>
            <DialogActions sx={{ position: 'sticky', bottom: 0, backgroundColor: 'background.paper', zIndex: 1000 }}>
                <Box sx={{ width: '100%', display: 'flex', justifyContent: 'space-between' }}>
                    <Button onClick={handleSubmit} variant="contained" startIcon={<SaveIcon />}>
                        确认
                    </Button>
                </Box>
            </DialogActions>
        </Dialog>
    );
}

export default InitModal;